@@ -1,20 +1,33 @@
 package Module::FeaturesUtil::Get;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-24'; # DATE
+our $DATE = '2021-02-25'; # DATE
 our $DIST = 'Module-FeaturesUtil-Get'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict 'subs', 'vars';
 use warnings;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
+                       get_feature_set_spec
                        get_features_decl
                        get_feature_val
                        module_declares_feature
                );
 
+sub get_feature_set_spec {
+    my ($fsetname, $load) = @_;
+
+    my $mod = "Module::Features::$fsetname";
+    if ($load) {
+        (my $modpm = "$mod.pm") =~ s!::!/!g;
+        eval { require $modpm; 1 };
+        last if $@;
+    }
+    return \%{"$mod\::FEATURES_DEF"};
+}
+
 sub get_features_decl {
     my ($mod, $load) = @_;
 
@@ -24,12 +37,15 @@ sub get_features_decl {
     {
         my $proxymod = "$mod\::_ModuleFeatures";
         (my $proxymodpm = "$proxymod.pm") =~ s!::!/!g;
-        $features_decl = \%{"$proxymod\::FEATURES"};
         if ($load) {
             eval { require $proxymodpm; 1 };
             last if $@;
         }
-        return $features_decl if scalar keys %$features_decl;
+        $features_decl = { %{"$proxymod\::FEATURES"} };
+        if (scalar keys %$features_decl) {
+            $features_decl->{"x.source"} = "pm:$proxymod";
+            return $features_decl;
+        }
     }
 
     # second, try to get features declaration from MODNAME %FEATURES
@@ -39,8 +55,9 @@ sub get_features_decl {
             eval { require $modpm; 1 };
             last if $@;
         }
-        $features_decl = \%{"$mod\::FEATURES"};
-        return $features_decl; # if scalar keys %$features_decl;
+        $features_decl = { %{"$mod\::FEATURES"} };
+        $features_decl->{"x.source"} = "pm:$mod";
+        return $features_decl;
     }
 
     {};
@@ -82,7 +99,7 @@ Module::FeaturesUtil::Get - Get a feature
 
 =head1 VERSION
 
-This document describes version 0.002 of Module::FeaturesUtil::Get (from Perl distribution Module-FeaturesUtil-Get), released on 2021-02-24.
+This document describes version 0.003 of Module::FeaturesUtil::Get (from Perl distribution Module-FeaturesUtil-Get), released on 2021-02-25.
 
 =head1 SYNOPSIS
 
@@ -111,6 +128,18 @@ This document describes version 0.002 of Module::FeaturesUtil::Get (from Perl di
 
 =head1 FUNCTIONS
 
+=head2 get_feature_set_spec
+
+Usage:
+
+ my $feature_set_spec = get_feature_set_spec($feature_set_name);
+
+Feature set specification will be retrieved from the
+C<Module::Features::$feature_set_name> module. The module will NOT be loaded by
+this routine; you will need to load the module yourself.
+
+This module will also NOT check the validity of feature set specification.
+
 =head2 get_features_decl
 
 Usage:
@@ -122,7 +151,7 @@ variable, then from the module's C<%FEATURES>. Proxy module is
 C<$module_name>I<::_ModuleFeatures>. You have to load the modules yourself; this
 routine will not load the modules for you.
 
-This module will also NOT check the validity of features declaration.
+This routine will also NOT check the validity of features declaration.
 
 =head2 get_feature_val
 
@@ -142,7 +171,8 @@ Get the value of a feature from a module's features declaration.
 
 Features declaration is retrieved using L</get_features_decl>.
 
-This routine will also NOT check the feature set specification.
+This routine will also NOT check the validity of feature value against the
+specification's schema.
 
 =head2 module_declares_feature
 
